@@ -22,15 +22,15 @@ def train_val_test_split_tabular(N,
                                                        train_size + val_size),
                                                    test_size=test_size,
                                                    stratify=stratify)
-    if stratify is not None:
-        stratify = stratify[idx_train_and_val]
-        idx_train, idx_val = train_test_split(idx_train_and_val,
-                                              random_state=random_state,
-                                              train_size=(
-                                                  train_size / (train_size + val_size)),
-                                              test_size=(
-                                                  val_size / (train_size + val_size)),
-                                              stratify=stratify)
+
+    stratify = stratify[idx_train_and_val]
+    idx_train, idx_val = train_test_split(idx_train_and_val,
+                                          random_state=random_state,
+                                          train_size=(
+                                              train_size / (train_size + val_size)),
+                                          test_size=(
+                                              val_size / (train_size + val_size)),
+                                          stratify=stratify)
 
     return idx_train, idx_val, idx_test
 
@@ -232,7 +232,7 @@ def process_planetoid_datasets(name, paths):
     attributes = sp.vstack((allx, tx)).tolil()
     attributes[test_idx_reorder, :] = attributes[test_idx_range, :]
 
-    adj = nx.adjacency_matrix(nx.from_dict_of_lists(
+    adj_matrix = nx.adjacency_matrix(nx.from_dict_of_lists(
         graph, create_using=nx.DiGraph()))
 
     labels = np.vstack((ally, ty))
@@ -244,7 +244,7 @@ def process_planetoid_datasets(name, paths):
 
     labels = labels.argmax(1)
 
-    adj = adj.astype('float32')
+    adj_matrix = adj_matrix.astype('float32')
     attributes = attributes.astype('float32')
 
-    return adj, attributes, labels, idx_train, idx_val, idx_test
+    return adj_matrix, attributes, labels, idx_train, idx_val, idx_test
